Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(194)

Unified Diff: test/cctest/test-heap.cc

Issue 139973004: A64: Synchronize with r15814. (Closed) Base URL: https://v8.googlecode.com/svn/branches/experimental/a64
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « test/cctest/test-debug.cc ('k') | test/cctest/test-heap-profiler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/cctest/test-heap.cc
diff --git a/test/cctest/test-heap.cc b/test/cctest/test-heap.cc
index 8221c6400bb572f5596097255d2ac8a6e1edb320..b0fd704c80310a13ee5c488c3eeb536e9dd4fb9f 100644
--- a/test/cctest/test-heap.cc
+++ b/test/cctest/test-heap.cc
@@ -127,7 +127,7 @@ static void CheckFindCodeObject(Isolate* isolate) {
Address obj_addr = obj->address();
for (int i = 0; i < obj->Size(); i += kPointerSize) {
- Object* found = heap->FindCodeObject(obj_addr + i);
+ Object* found = isolate->FindCodeObject(obj_addr + i);
CHECK_EQ(code, found);
}
@@ -137,8 +137,8 @@ static void CheckFindCodeObject(Isolate* isolate) {
Handle<Code>())->ToObjectChecked();
CHECK(copy->IsCode());
HeapObject* obj_copy = HeapObject::cast(copy);
- Object* not_right = heap->FindCodeObject(obj_copy->address() +
- obj_copy->Size() / 2);
+ Object* not_right = isolate->FindCodeObject(obj_copy->address() +
+ obj_copy->Size() / 2);
CHECK(not_right != code);
}
@@ -661,7 +661,7 @@ TEST(ObjectProperties) {
CHECK(obj->HasLocalProperty(*first));
// delete first
- CHECK(obj->DeleteProperty(*first, JSObject::NORMAL_DELETION));
+ JSReceiver::DeleteProperty(obj, first, JSReceiver::NORMAL_DELETION);
CHECK(!obj->HasLocalProperty(*first));
// add first and then second
@@ -673,9 +673,9 @@ TEST(ObjectProperties) {
CHECK(obj->HasLocalProperty(*second));
// delete first and then second
- CHECK(obj->DeleteProperty(*first, JSObject::NORMAL_DELETION));
+ JSReceiver::DeleteProperty(obj, first, JSReceiver::NORMAL_DELETION);
CHECK(obj->HasLocalProperty(*second));
- CHECK(obj->DeleteProperty(*second, JSObject::NORMAL_DELETION));
+ JSReceiver::DeleteProperty(obj, second, JSReceiver::NORMAL_DELETION);
CHECK(!obj->HasLocalProperty(*first));
CHECK(!obj->HasLocalProperty(*second));
@@ -688,9 +688,9 @@ TEST(ObjectProperties) {
CHECK(obj->HasLocalProperty(*second));
// delete second and then first
- CHECK(obj->DeleteProperty(*second, JSObject::NORMAL_DELETION));
+ JSReceiver::DeleteProperty(obj, second, JSReceiver::NORMAL_DELETION);
CHECK(obj->HasLocalProperty(*first));
- CHECK(obj->DeleteProperty(*first, JSObject::NORMAL_DELETION));
+ JSReceiver::DeleteProperty(obj, first, JSReceiver::NORMAL_DELETION);
CHECK(!obj->HasLocalProperty(*first));
CHECK(!obj->HasLocalProperty(*second));
@@ -1948,7 +1948,7 @@ TEST(PrototypeTransitionClearing) {
// Verify that only dead prototype transitions are cleared.
CHECK_EQ(10, baseObject->map()->NumberOfProtoTransitions());
- HEAP->CollectAllGarbage(Heap::kNoGCFlags);
+ HEAP->CollectAllGarbage(Heap::kAbortIncrementalMarkingMask);
const int transitions = 10 - 3;
CHECK_EQ(transitions, baseObject->map()->NumberOfProtoTransitions());
@@ -3170,7 +3170,7 @@ TEST(Regress169928) {
array_data->set(1, Smi::FromInt(2));
AllocateAllButNBytes(HEAP->new_space(),
- JSArray::kSize + AllocationSiteInfo::kSize +
+ JSArray::kSize + AllocationMemento::kSize +
kPointerSize);
Handle<JSArray> array = factory->NewJSArrayWithElements(array_data,
@@ -3180,16 +3180,16 @@ TEST(Regress169928) {
CHECK_EQ(Smi::FromInt(2), array->length());
CHECK(array->HasFastSmiOrObjectElements());
// We need filler the size of AllocationSiteInfo object, plus an extra
// fill pointer value.
MaybeObject* maybe_object = HEAP->AllocateRaw(
- AllocationSiteInfo::kSize + kPointerSize, NEW_SPACE, OLD_POINTER_SPACE);
+ AllocationMemento::kSize + kPointerSize, NEW_SPACE, OLD_POINTER_SPACE);
Object* obj = NULL;
CHECK(maybe_object->ToObject(&obj));
Address addr_obj = reinterpret_cast<Address>(
reinterpret_cast<byte*>(obj - kHeapObjectTag));
HEAP->CreateFillerObjectAt(addr_obj,
- AllocationSiteInfo::kSize + kPointerSize);
+ AllocationMemento::kSize + kPointerSize);
// Give the array a name, making sure not to allocate strings.
v8::Handle<v8::Object> array_obj = v8::Utils::ToLocal(array);
« no previous file with comments | « test/cctest/test-debug.cc ('k') | test/cctest/test-heap-profiler.cc » ('j') | no next file with comments »
@@ -3180,16 +3180,16 @@ TEST(Regress169928) {
CHECK_EQ(Smi::FromInt(2), array->length());
CHECK(array->HasFastSmiOrObjectElements());
- // We need filler the size of AllocationSiteInfo object, plus an extra
+ // We need filler the size of AllocationMemento object, plus an extra
// fill pointer value.
MaybeObject* maybe_object = HEAP->AllocateRaw(

Powered by Google App Engine
This is Rietveld 408576698